<?php

session_start();

class formLoader {

	/**
	 * Form structure
	 *
	 * @var object
	 **/
	var $form_data;

	/**
	 * Form action
	 *
	 * @var string
	 **/
	var $action;
	
	
	/**
	 * Constructor
	 *
	 * @param string $form_json
	 * @return void
	 * @access public
	 **/
	public function __construct($form_json, $form_action)
	{
		$this->form_data = json_decode(str_replace('\\', '', $form_json));
		$this->action = $form_action;
	}

	/**
	 * Render the form
	 *
	 * @return void
	 * @access public 
	 **/
	public function render_form()
	{
		if( empty($this->form_data) || empty($this->action) ) {
			throw new Exception("Error Processing Request", 1);
		}

		$fields = '';

		foreach ($this->form_data->fields as $field) {
			
			// Single line text
			if($field->type == 'element-single-line-text' ) {
				$fields .= $this->element_single_line_text($field);
			}
			
			// Email
			if($field->type == 'element-email' ) {
				$fields .= $this->element_email($field);
			}
			
			// Date
			if($field->type == 'element-date' ) {
				$fields .= $this->element_date($field);
			}
			
			// File Upload
			if($field->type == 'element-file-upload' ) {
				$fields .= $this->element_file_upload($field);
			}

			// Number
			if($field->type == 'element-number') {
				$fields .= $this->element_number($field);
			}

			// Paragraph text
			if($field->type == 'element-paragraph-text') {
				$fields .= $this->element_paragraph_text($field);
			}

			// Checkboxes
			if($field->type == 'element-checkboxes') {
				$fields .= $this->element_checkboxes($field);
			}

			// Multiple choice
			if($field->type == 'element-multiple-choice') {
				$fields .= $this->element_multiple_choice($field);
			}

			// Dropdown
			if($field->type == 'element-dropdown') {
				$fields .= $this->element_dropdown($field);
			}

			// Section break
			if($field->type == 'element-section-break') {
				$fields .= $this->element_section_break($field);
			}

		}

		$form = $this->open_form($fields);
		echo $form;
        
		
	}

	/**
	 * Render the form header
	 *
	 * @param object $fields
	 * @return string $html
	 * @access private 
	 **/
	private function open_form($fields)
	{
		
		include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/database.php";
		
		include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/connect-db.php";
		
		$account = $_SESSION["account"];
		
		$user_db_id = $_SESSION["user_db_id"];
		
		$_SESSION["user_db_id"] = $user_db_id;

        $_SESSION['account'] = $account;
		
		$html = sprintf('<form action="'.$domainname.'/formbuilder/submit.php" method="post" enctype="multipart/form-data" accept-charset="utf-8" role="form">');
		$html .= '<div class="form-title">';
		$html .= file_get_contents("forms/".$user_db_id."/header.php");
		$html .= $fields;
		$html .= '<br>Type the code from the image below:';
		$html .= '<br><img src="'.$domainname.'/formbuilder/core/captcha/captcha.php" border="0" title="captcha_code">';
		$html .= '&nbsp;&nbsp;&nbsp;<input type="text" name="captcha_code:" size="5" required>';
		$html .= '<br><br><button type="submit" class="btn btn-primary">Submit</button>';
		$html .= '</div></form>';
				
		
$header = '	
<html>
<head>
	<title>YOUR FORM - Form</title>
	<link rel="stylesheet" href="'.$domainname.'/formbuilder/core/bootstrap-3.1.1/dist/css/bootstrap.min.css" />
    <link rel="stylesheet" href="'.$domainname.'/formbuilder/core/jquery-ui-1.12.1/jquery-ui.css">
    <link rel="icon" href="'.$domainname.'/formbuilder/core/img/favicon.png" type="image/png" />
    <script src="'.$domainname.'/formbuilder/core/js/jquery-1.12.4.js"></script>
    <script src="'.$domainname.'/formbuilder/core/jquery-ui-1.12.1/jquery-ui.js"></script>
    <script>$(function() {
        $( ".datepicker" ).datepicker({
            dateFormat : "dd/mm/yy",
            changeMonth : true,
            changeYear : true,
            yearRange: "1900:2100",
            maxDate: "-1d"
        });
    });
	</script>
</head>
<body>
	<div class="container">
		<div class="col-sm-6 col-sm-offset-3" style="width: 1100px; right: 30%;"><?php session_start(); $_SESSION["submittable"] = "'.$this->form_data->title.'";
		$account = "'.$account.'"; $_SESSION["account"] = $account; $user_db_id = '.$user_db_id.'; $_SESSION["user_db_id"] = $user_db_id; ?>';
			
$footer = '</div>
	</div>
</body>
</html>';

            				
		$fp_users = fopen('forms/'.$user_db_id.'/'.$this->form_data->title.'.php', 'w');
		fwrite($fp_users, $header);
        fwrite($fp_users, $html);
		fwrite($fp_users, $footer);
		fclose($fp_users);
				
		
		return $html;		
		

	}

	/**
	 * Encode element title
	 *
	 * @param string $title
	 * @return string $str
	 * @access private 
	 **/
	private function encode_element_title($title)
	{
		$str = str_replace(' ', '_', strtolower($title));
		$str = preg_replace("/[^a-zA-Z0-9]/", "", $str);
		$str = htmlentities($str, ENT_QUOTES, 'UTF-8');
		$str = html_entity_decode($str, ENT_QUOTES, 'UTF-8');

		return $str;
	}

	/**
	 * Get formatted label for form element
	 *
	 * @param string $id
	 * @param string $title
	 * @param mixed $required
	 * @return string
	 * @access private
	 **/
	private function make_label($id, $title, $required)
	{
		if( $required ) {
			$html = sprintf('<label for="%s">%s <span style="color: red">* </span></label>', $id, $title);
		} else {
			$html = sprintf('<label for="%s">%s </label>', $id, $title);
		}

		return $html;
	}

	/**
	 * Render single line text
	 *
	 * @param object $field
	 * @return string $html
	 * @access private 
	 **/
	private function element_single_line_text($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
	    $html .= sprintf('<input type="text" name="%s" id="%s" class="form-control" %s>', $id, $id, $required);
	  	
		    require 'database.php';
						
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
             $filename = $this->form_data->title;			 
			  
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		
		$html .= '</div>';

	  	return $html;
	}
	
	private function element_email($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
	    $html .= sprintf('<input type="text" name="email_adress:" id="%s" class="form-control" %s>', $id, $required);
	  	
		    require 'database.php';
						
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
             $filename = $this->form_data->title;			 
			  
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		
		$html .= '</div>';

	  	return $html;
	}
	
	private function element_date($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
		$html .= sprintf('<input type="text" name="%s" id="%s" class="form-control datepicker" %s>', $id, $id, $required);
	  	
		    require 'database.php';
						
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
             $filename = $this->form_data->title;			 
			  
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		
		$html .= '</div>';

	  	return $html;
	}
	
	private function element_file_upload($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$filename = $this->form_data->title;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];
		
		
		
		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
		$html .= sprintf('<input class="note-image-input" type="file" id="file" name="files[]" multiple="multiple" class="form-control" %s>', $required);
		$html .= '<?php session_start(); $_SESSION["file_upload"] = "'.$id.'"; ?>';
	    
			  	
		    require 'database.php';
			
			
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
             $filename = $this->form_data->title;			 
			  
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		            

	  	    $html .= '</div>';

	    	return $html;
	  	
	}

	/**
	 * Render number
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_number($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
	    $html .= sprintf('<input type="number" name="%s" id="%s" class="form-control" %s>', $id, $id, $required);
		
		    
			require 'database.php';
			
			
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
			 $filename = $this->form_data->title;
			 
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		
	  	$html .= '</div>';

	  	return $html;
	}

	/**
	 * Render paragraph text
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_paragraph_text($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 70%;">';
		$html .= $this->make_label($id, $field->title, $required);
	    $html .= sprintf('<textarea id="%s" name="%s" class="form-control" rows="7" %s></textarea>', $id, $id, $required);
		
		    
			require 'database.php';
			
			
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
			 $filename = $this->form_data->title;
			 
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, value) VALUES ('$id', '$label', '$value')";
             $conn->query($sql_insert);
			 $conn->close();
		
	  	$html .= '</div>';

	  	return $html;
	}

	/**
	 * Checkboxes
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_checkboxes($field)
	{
		error_log('message');
		
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$filename = $this->form_data->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group">';
		$html .= $this->make_label($id, $field->title, $required);
		
		    
			require 'database.php';
			
			
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
			 $pool = "qwertzupasdfghkyxcvbnm";
             $pool .= "23456789";
             $pool .= "WERTZUPLKJHGFDSAYXCVBNM";

             srand ((double)microtime()*1000000);
             for($index = 0; $index < 5; $index++)

             {
             $pass_word .= substr($pool,(rand()%(strlen ($pool))), 1);
             }

             $str = $pass_word;

             $md5_diagram = md5($str);
			 
			 $sql_create_diagram = "CREATE TABLE `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."` (
             id INT(6) UNSIGNED AUTO_INCREMENT PRIMARY KEY, 
             field VARCHAR(2000) NOT NULL,
			 label VARCHAR(2000) NOT NULL,
			 md5 VARCHAR(2000) NOT NULL,
             value VARCHAR(2000) NOT NULL,
             sum VARCHAR(2000) NOT NULL
             )";
             $conn->query($sql_create_diagram);
			 
			 $usercharts_url = ''.$filename.'_users_charts_'.$md5_diagram.'.php';
		     $sql_charts = "INSERT INTO `EN_".$user_db_id."_".$filename."_users_charts`(field, label, md5, chart_url) VALUES ('$id', '$label', '$md5_diagram', '$usercharts_url')";
		     $conn->query($sql_charts);
			 
		     $conn->close();
			 			 
			 		
	    // Render choices
		for($i=0; $i < count($field->choices); $i++) {
			$checked = $field->choices[$i]->checked ? "checked" : '';

			$html .= '<div class="checkbox"><label>';
			$html .= sprintf('<input type="checkbox" name="%s[]" id="%s-%d" value="%s" %s>%s', $id, $id, $i, $field->choices[$i]->value, $checked, $field->choices[$i]->title);
			$html .= '</label></div>';
			
			
			require 'database.php';
			
			
        // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
			 
			 $value = $field->choices[$i]->value;
			 $score = $field->choices[$i]->score;
			 $feld = ''.$id.'_'.$i.'';
			 $filename = $this->form_data->title;
			 $checkbox_chart = $id;
			 		 
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, md5, value, score) VALUES ('$id', '$label', '$md5_diagram', '$value', '$score')";
             $conn->query($sql_insert);
			 
			 $sql_diagram = "INSERT INTO `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."`(field, label, md5, value) VALUES ('$id', '$label', '$md5_diagram', '$value')";
             $conn->query($sql_diagram);
			 
			 $conn->close();
		}

	  	$html .= '<?php session_start(); $_SESSION["checkbox_chart"] = "'.$id.'";?>';
		
		$html .= '</div>';
		
			
		$fp_users_bar_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_bar_chart.php', 'w');
		
		$users_bar_chart = 
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
         }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
		
		fwrite($fp_users_bar_chart, $users_bar_chart);
		
		fclose($fp_users_bar_chart);
		
		
		$fp_users_column_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_column_chart.php', 'w');
		
		$users_column_chart = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
        }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
	   
	    fwrite($fp_users_column_chart, $users_column_chart);
		
	    fclose($fp_users_column_chart);
		
		
		$fp_users_pie_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_pie_chart.php', 'w');
		
		$users_pie_chart_1 = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $rows[]=array("c"=>array("0"=>array("v"=>$result["value"],"f"=>NULL),"1"=>array("v"=>(int)$result["sum"],"f" =>NULL)));
  
        }';
		
		$users_pie_chart_2 =
		
		'echo $format = ';
		
		$users_pie_chart_3 =
		
		"'{";
		
		$users_pie_chart_4 =
		
        '"cols":
        [
        {"id":"","label":"Subject","pattern":"","type":"string"},
        {"id":"","label":"Number","pattern":"","type":"number"}
        ],
        "rows":';
		
		$users_pie_chart_5 =
		
		"'.json_encode";
		
		$users_pie_chart_6 =
		
		'($rows).';
		
		$users_pie_chart_7 =
		
		"'}';

        ?>";
		
		fwrite($fp_users_pie_chart, $users_pie_chart_1);
		fwrite($fp_users_pie_chart, $users_pie_chart_2);
		fwrite($fp_users_pie_chart, $users_pie_chart_3);
		fwrite($fp_users_pie_chart, $users_pie_chart_4);
		fwrite($fp_users_pie_chart, $users_pie_chart_5);
		fwrite($fp_users_pie_chart, $users_pie_chart_6);
		fwrite($fp_users_pie_chart, $users_pie_chart_7);
		
		
	    fclose($fp_users_pie_chart);

	  	return $html;
	}

	/**
	 * Mutliple choice
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_multiple_choice($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$filename = $this->form_data->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group">';
		$html .= $this->make_label($id, $field->title, $required);
		
		    require 'database.php';
		
		// Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
			 
			 $pool = "qwertzupasdfghkyxcvbnm";
             $pool .= "23456789";
             $pool .= "WERTZUPLKJHGFDSAYXCVBNM";

             srand ((double)microtime()*1000000);
             for($index = 0; $index < 5; $index++)

             {
             $pass_word .= substr($pool,(rand()%(strlen ($pool))), 1);
             }

             $str = $pass_word;

             $md5_diagram = md5($str);
			 
			 $usercharts_url = ''.$filename.'_users_charts_'.$md5_diagram.'.php';
		     $sql_charts = "INSERT INTO `EN_".$user_db_id."_".$filename."_users_charts`(field, label, md5, chart_url) VALUES ('$id', '$label', '$md5_diagram', '$usercharts_url')";
		     $conn->query($sql_charts);
			 
		$conn->close();
			 		
	    // Render choices
		for($i=0; $i < count($field->choices); $i++) {
			$checked = $field->choices[$i]->checked ? "checked" : '';

			$html .= '<div class="radio"><label>';
			$html .= sprintf('<input type="radio" name="%s" id="%s_%d" value="%s" %s>%s', $id, $id, $i, $field->choices[$i]->value, $checked, $field->choices[$i]->title);
			$html .= '</label></div>';
			
			$value = $field->choices[$i]->value;
			$score = $field->choices[$i]->score;
			
			require 'database.php'; 
		  
		 // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }

        			 
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, md5, value, score) VALUES ('$id', '$label', '$md5_diagram', '$value', '$score')";
             $conn->query($sql_insert);
			 
			 $sql_create_diagram = "CREATE TABLE `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."` (
             id INT(6) UNSIGNED AUTO_INCREMENT PRIMARY KEY, 
             field VARCHAR(2000) NOT NULL,
			 label VARCHAR(2000) NOT NULL,
			 md5 VARCHAR(2000) NOT NULL,
             value VARCHAR(2000) NOT NULL,
             sum VARCHAR(2000) NOT NULL
             )";
             $conn->query($sql_create_diagram);
			 
			 $sql_diagram = "INSERT INTO `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."`(field, label, md5, value) VALUES ('$id', '$label', '$md5_diagram', '$value')";
             $conn->query($sql_diagram);
			 
			 $conn->close();
		}

	  	$html .= '</div>';
				
		
		$fp_users_bar_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_bar_chart.php', 'w');
		
		$users_bar_chart = 
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
         }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
		
		fwrite($fp_users_bar_chart, $users_bar_chart);
		
		fclose($fp_users_bar_chart);
		
		
		$fp_users_column_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_column_chart.php', 'w');
		
		$users_column_chart = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
        }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
	   
	    fwrite($fp_users_column_chart, $users_column_chart);
		
	    fclose($fp_users_column_chart);
		
		
		$fp_users_pie_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_pie_chart.php', 'w');
		
		$users_pie_chart_1 = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $rows[]=array("c"=>array("0"=>array("v"=>$result["value"],"f"=>NULL),"1"=>array("v"=>(int)$result["sum"],"f" =>NULL)));
  
        }';
		
		$users_pie_chart_2 =
		
		'echo $format = ';
		
		$users_pie_chart_3 =
		
		"'{";
		
		$users_pie_chart_4 =
		
        '"cols":
        [
        {"id":"","label":"Subject","pattern":"","type":"string"},
        {"id":"","label":"Number","pattern":"","type":"number"}
        ],
        "rows":';
		
		$users_pie_chart_5 =
		
		"'.json_encode";
		
		$users_pie_chart_6 =
		
		'($rows).';
		
		$users_pie_chart_7 =
		
		"'}';

        ?>";
		
		fwrite($fp_users_pie_chart, $users_pie_chart_1);
		fwrite($fp_users_pie_chart, $users_pie_chart_2);
		fwrite($fp_users_pie_chart, $users_pie_chart_3);
		fwrite($fp_users_pie_chart, $users_pie_chart_4);
		fwrite($fp_users_pie_chart, $users_pie_chart_5);
		fwrite($fp_users_pie_chart, $users_pie_chart_6);
		fwrite($fp_users_pie_chart, $users_pie_chart_7);
		
		
	    fclose($fp_users_pie_chart);

	  	return $html;
	}

	/**
	 * Render dropdown
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_dropdown($field)
	{
		$id = $this->encode_element_title($field->title);
		$label = $field->title;
		$filename = $this->form_data->title;
		$required = ($field->required) ? 'required' : FALSE;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];

		$html = '<div class="form-group" style="width: 30%;">';
		$html .= $this->make_label($id, $field->title, $required);
	    $html .= sprintf('<select name="%s" id="%s" class="form-control" %s>', $id, $id, $required);
		
		    require 'database.php'; 
		  
		 // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
		
		     $pool = "qwertzupasdfghkyxcvbnm";
             $pool .= "23456789";
             $pool .= "WERTZUPLKJHGFDSAYXCVBNM";

             srand ((double)microtime()*1000000);
             for($index = 0; $index < 5; $index++)

             {
             $pass_word .= substr($pool,(rand()%(strlen ($pool))), 1);
             }

             $str = $pass_word;

             $md5_diagram = md5($str);
			 
			 $usercharts_url = ''.$filename.'_users_charts_'.$md5_diagram.'.php';
		     $sql_charts = "INSERT INTO `EN_".$user_db_id."_".$filename."_users_charts`(field, label, md5, chart_url) VALUES ('$id', '$label', '$md5_diagram', '$usercharts_url')";
		     $conn->query($sql_charts);
			 
		     $conn->close();

	    // Render choices
	    foreach ($field->choices as $choice) {
	    	$checked = $choice->checked ? "selected" : '';
	    	$html .= sprintf('<option value="%s" %s>%s</option>', $choice->value, $checked, $choice->title);
						
			 $value = $choice->value;
			 
			 require 'database.php';
		  
		 // Create connection
            $conn = new mysqli($servername, $username, $password, $dbname);
       // Check connection
            if ($conn->connect_error) {
            die("Connection failed: " . $conn->connect_error);
             }
						 			 		 
			 $sql_insert = "INSERT INTO `EN_".$user_db_id."_".$filename."`(field, label, md5, value) VALUES ('$id', '$label', '$md5_diagram', '$value')";
             $conn->query($sql_insert);
			 
			 $sql_create_diagram = "CREATE TABLE `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."` (
             id INT(6) UNSIGNED AUTO_INCREMENT PRIMARY KEY, 
             field VARCHAR(2000) NOT NULL,
			 label VARCHAR(2000) NOT NULL,
			 md5 VARCHAR(2000) NOT NULL,
             value VARCHAR(2000) NOT NULL,
             sum VARCHAR(2000) NOT NULL
             )";
             $conn->query($sql_create_diagram);
			 
			 $sql_diagram = "INSERT INTO `EN_".$user_db_id."_".$filename."_diagram_".$md5_diagram."`(field, label, md5, value) VALUES ('$id', '$label', '$md5_diagram', '$value')";
             $conn->query($sql_diagram);
			 
			 $conn->close();
	    }

	  	$html .= '</select></div>';
				
		$fp_users_bar_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_bar_chart.php', 'w');
		
		$users_bar_chart = 
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
         }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
		
		fwrite($fp_users_bar_chart, $users_bar_chart);
		
		fclose($fp_users_bar_chart);
		
		
		$fp_users_column_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_column_chart.php', 'w');
		
		$users_column_chart = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $data[] = array("Employee","Markes");
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $data[] = array($result["value"],(int)$result["sum"]);
  
        }

        //	$data = array($data);			
        echo json_encode($data);
        ?>';
	   
	    fwrite($fp_users_column_chart, $users_column_chart);
		
	    fclose($fp_users_column_chart);
		
		
		$fp_users_pie_chart = fopen('forms/'.$user_db_id.'/'.$user_db_id.'/'.$filename.'/'.$filename.'_'.$md5_diagram.'_pie_chart.php', 'w');
		
		$users_pie_chart_1 = 
		
		'<?php
        include $_SERVER["DOCUMENT_ROOT"]."/formbuilder/db.php";
        $sql = "select * from `EN_'.$user_db_id.'_'.$filename.'_diagram_'.$md5_diagram.'`";
        $query = mysql_query($sql);
        while($result = mysql_fetch_array($query))
        {
        $rows[]=array("c"=>array("0"=>array("v"=>$result["value"],"f"=>NULL),"1"=>array("v"=>(int)$result["sum"],"f" =>NULL)));
  
        }';
		
		$users_pie_chart_2 =
		
		'echo $format = ';
		
		$users_pie_chart_3 =
		
		"'{";
		
		$users_pie_chart_4 =
		
        '"cols":
        [
        {"id":"","label":"Subject","pattern":"","type":"string"},
        {"id":"","label":"Number","pattern":"","type":"number"}
        ],
        "rows":';
		
		$users_pie_chart_5 =
		
		"'.json_encode";
		
		$users_pie_chart_6 =
		
		'($rows).';
		
		$users_pie_chart_7 =
		
		"'}';

        ?>";
		
		fwrite($fp_users_pie_chart, $users_pie_chart_1);
		fwrite($fp_users_pie_chart, $users_pie_chart_2);
		fwrite($fp_users_pie_chart, $users_pie_chart_3);
		fwrite($fp_users_pie_chart, $users_pie_chart_4);
		fwrite($fp_users_pie_chart, $users_pie_chart_5);
		fwrite($fp_users_pie_chart, $users_pie_chart_6);
		fwrite($fp_users_pie_chart, $users_pie_chart_7);
		
		
	    fclose($fp_users_pie_chart);

	  	return $html;
	}

	/**
	 * Section break
	 *
	 * @param object $field
	 * @return string $html
	 * @access private
	 **/
	private function element_section_break($field)
	{
		$file = $field->title;
		$account = $_SESSION["account"];
		$user_db_id = $_SESSION["user_db_id"];
		$html = '<div class="form-group section-break">';
		$html .= file_get_contents("forms/".$user_db_id."/".$user_db_id."/temp/".$file.".php");
		$html .= '</div>';
				 
		return $html;
	}

} // End formLoader.php
?>